.. This file is part of Invenio
   Copyright (C) 2015 CERN.

   Invenio is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   Invenio is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Invenio; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

Mailing lists
=============

There are several Invenio-related mailing lists that you can subscribe
to or read the archives of.

``project-invenio-announce@cern.ch``
------------------------------------

  Low-volume read-only moderated mailing list to announce new Invenio releases
  and other major news concerning the project. Every Invenio user is strongly
  encouraged to subscribe to this list.

  - `p-i-a (un)subscribe <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-announce>`_
  - `p-i-a new archives <https://groups.cern.ch/group/project-invenio-announce/Lists/Archive/100.aspx>`_
  - `p-i-a old archives <https://groups.cern.ch/group/project-cdsware-announce/Lists/Archive/100.aspx>`_
  - `p-i-a very old archives <http://cdsware.cern.ch/lists/project-cdsware-announce/archive/>`_

``project-invenio-general@cern.ch``
-----------------------------------

  Possibly high-volume mailing list, intended for discussion among users and
  administrators of Invenio instances.

  - `p-i-g (un)subscribe <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-general>`_
  - `p-i-g new archives <https://groups.cern.ch/group/project-invenio-general/Lists/Archive/100.aspx>`_
  - `p-i-g old archives <https://groups.cern.ch/group/project-cdsware-users/Lists/Archive/100.aspx>`_
  - `p-i-g very old archives <http://cdsware.cern.ch/lists/project-cdsware-users/archive/>`_

``project-invenio-devel@cern.ch``
---------------------------------

  Possibly high-volume mailing list, intended for discussion among Invenio
  developers and hackers.

  - `p-i-d (un)subscribe <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-devel>`_
  - `p-i-d new archives <https://groups.cern.ch/group/project-invenio-devel/Lists/Archive/100.aspx>`_
  - `p-i-d old archives <https://groups.cern.ch/group/project-cdsware-developers/Lists/Archive/100.aspx>`_
  - `p-i-d very old archives <http://cdsware.cern.ch/lists/project-cdsware-developers/archive/>`_

Note that all the mailing lists are also archived (as of the 20th of
July, 2011) on `The Mail Archive <http://www.mail-archive.com/>`__. As
soon as possible we will upload there also all the previous historical
archives.

``github.com/inveniosoftware``
------------------------------

Most of the developer communication is happening nowadays on GitHub, not on the
mailing lists. You are stroungly encouraged to join
`<https://github.com/orgs/inveniosoftware/teams/developers>`_ team and watch
notifications from various `<https://github.com/inveniosoftware/>`_ organisation
repositories of interest.
